import {isEmpty as _isEmpty} from 'lodash-es'
/**
 * 返回整理过的净值数值
 * @param value {String | Number | null } 原始数据
 * @param isPer {Boolean} 是否添加百分号
 * @returns {String}
 */
export const initPercent = (value, isPer= true) => {
  if (isEmpty(value)) {
    return null
  } else {
    if (+value === 0) {
      return '0'
    } else {
      return (+value).toFixed(2)+ (isPer ? '%' : '')
    }
  }
}
/**
 * 判断对象是否为空，或者基础类型转换boolean为false，对lodash做了基础类型判断
 * @param params {String | Object | Number | Null | Boolean}
 */
export const isEmpty = (params) => {
  if (typeof params === 'number') {
    return false
  } else if (typeof String !== 'object') {
    return !params
  } else {
    return _isEmpty(params)
  }
}

/**
 * 根据rem返回当前分辨率的真实px
 * @param rem {Number} 要返回的rem
 * @returns {Number} 当前px
 */
export const rem2px = (rem) => {
  return window.innerWidth / 750 * rem
}

/**
 * 格式化时间
 * @param date {String | Date} 时间对象或时间戳
 * @param formatter {String} 时间格式 'yyyy-MM-dd hh:mm:ss'
 */
export const dateFormatter = (date, formatter) => {
  let newDate = date
  if (typeof date === 'string') {
    newDate = new Date(date)
  }
  const o = {
    'M+': newDate.getMonth() + 1, //月份
    'd+': newDate.getDate(), //日
    'h+': newDate.getHours(), //小时
    'm+': newDate.getMinutes(), //分
    's+': newDate.getSeconds() //秒
  }
  if (/(y+)/.test(formatter)) formatter = formatter.replace(RegExp.$1, (date.getFullYear() + '').substr(4 - RegExp.$1.length))
  for (const k in o)
    if (new RegExp('(' + k + ')').test(formatter))
      formatter = formatter.replace(RegExp.$1, RegExp.$1.length == 1 ? o[k] : ('00' + o[k]).substr(('' + o[k]).length))
  return formatter
}